@@ -1,30 +1,34 @@
 #
 # This file is part of pyasn1 software.
 #
-# Copyright (c) 2005-2020, Ilya Etingof <etingof@gmail.com>
+# Copyright (c) 2005-2019, Ilya Etingof <etingof@gmail.com>
 # License: http://snmplabs.com/pyasn1/license.html
 #
 import sys
 
-from pyasn1 import debug, error
+from pyasn1 import debug
+from pyasn1 import error
 from pyasn1.codec.ber import eoo
 from pyasn1.compat.integer import to_bytes
 from pyasn1.compat.octets import (
     int2oct,
-    ints2octs,
-    isOctetsType,
-    null,
     oct2int,
+    ints2octs,
+    null,
     str2octs,
+    isOctetsType,
 )
-from pyasn1.type import char, tag, univ, useful
+from pyasn1.type import char
+from pyasn1.type import tag
+from pyasn1.type import univ
+from pyasn1.type import useful
 
-__all__ = ["Encoder", "encode"]
+__all__ = ["encode"]
 
 LOG = debug.registerLoggee(__name__, flags=debug.DEBUG_ENCODER)
 
 
-class AbstractItemEncoder:
+class AbstractItemEncoder(object):
     supportIndefLenMode = True
 
     # An outcome of otherwise legit call `encodeFun(eoo.endOfOctets)`
@@ -106,7 +110,7 @@ class AbstractItemEncoder:
 
                 except error.PyAsn1Error:
                     exc = sys.exc_info()
-                    raise error.PyAsn1Error(f"Error encoding {value!r}: {exc[1]}")
+                    raise error.PyAsn1Error("Error encoding %r: %s" % (value, exc[1]))
 
                 if LOG:
                     LOG(
@@ -319,7 +323,7 @@ class ObjectIdentifierEncoder(AbstractItemEncoder):
             second = oid[1]
 
         except IndexError:
-            raise error.PyAsn1Error(f"Short OID {value}")
+            raise error.PyAsn1Error("Short OID %s" % (value,))
 
         if 0 <= second <= 39:
             if first == 1:
@@ -329,13 +333,13 @@ class ObjectIdentifierEncoder(AbstractItemEncoder):
             elif first == 2:
                 oid = (second + 80,) + oid[2:]
             else:
-                raise error.PyAsn1Error(f"Impossible first/second arcs at {value}")
+                raise error.PyAsn1Error("Impossible first/second arcs at %s" % (value,))
 
         elif first == 2:
             oid = (second + 80,) + oid[2:]
 
         else:
-            raise error.PyAsn1Error(f"Impossible first/second arcs at {value}")
+            raise error.PyAsn1Error("Impossible first/second arcs at %s" % (value,))
 
         octets = ()
 
@@ -358,7 +362,7 @@ class ObjectIdentifierEncoder(AbstractItemEncoder):
                 octets += res
 
             else:
-                raise error.PyAsn1Error(f"Negative OID arc {subOid} at {value}")
+                raise error.PyAsn1Error("Negative OID arc %s at %s" % (subOid, value))
 
         return octets, False, False
 
@@ -564,12 +568,12 @@ class SequenceEncoder(AbstractItemEncoder):
 
                     if namedType.isOptional and not component.isValue:
                         if LOG:
-                            LOG(f"not encoding OPTIONAL component {namedType!r}")
+                            LOG("not encoding OPTIONAL component %r" % (namedType,))
                         continue
 
                     if namedType.isDefaulted and component == namedType.asn1Object:
                         if LOG:
-                            LOG(f"not encoding DEFAULT component {namedType!r}")
+                            LOG("not encoding DEFAULT component %r" % (namedType,))
                         continue
 
                     if omitEmptyOptionals:
@@ -585,7 +589,7 @@ class SequenceEncoder(AbstractItemEncoder):
                         substrate += encodeFun(
                             component,
                             asn1Spec,
-                            **dict(options, wrapType=wrapType.componentType),
+                            **dict(options, wrapType=wrapType.componentType)
                         )
 
                     else:
@@ -598,7 +602,7 @@ class SequenceEncoder(AbstractItemEncoder):
                             substrate += encodeFun(chunk, wrapType, **options)
 
                             if LOG:
-                                LOG(f"wrapped with wrap type {wrapType!r}")
+                                LOG("wrapped with wrap type %r" % (wrapType,))
 
                 else:
                     substrate += encodeFun(component, asn1Spec, **options)
@@ -612,17 +616,17 @@ class SequenceEncoder(AbstractItemEncoder):
 
                 except KeyError:
                     raise error.PyAsn1Error(
-                        f'Component name "{namedType.name}" not found in {value!r}'
+                        'Component name "%s" not found in %r' % (namedType.name, value)
                     )
 
                 if namedType.isOptional and namedType.name not in value:
                     if LOG:
-                        LOG(f"not encoding OPTIONAL component {namedType!r}")
+                        LOG("not encoding OPTIONAL component %r" % (namedType,))
                     continue
 
                 if namedType.isDefaulted and component == namedType.asn1Object:
                     if LOG:
-                        LOG(f"not encoding DEFAULT component {namedType!r}")
+                        LOG("not encoding DEFAULT component %r" % (namedType,))
                     continue
 
                 if omitEmptyOptionals:
@@ -641,7 +645,7 @@ class SequenceEncoder(AbstractItemEncoder):
                         substrate += encodeFun(
                             component,
                             componentSpec,
-                            **dict(options, wrapType=componentSpec.componentType),
+                            **dict(options, wrapType=componentSpec.componentType)
                         )
 
                     else:
@@ -654,7 +658,7 @@ class SequenceEncoder(AbstractItemEncoder):
                             substrate += encodeFun(chunk, componentSpec, **options)
 
                             if LOG:
-                                LOG(f"wrapped with wrap type {componentSpec!r}")
+                                LOG("wrapped with wrap type %r" % (componentSpec,))
 
                 else:
                     substrate += encodeFun(component, componentSpec, **options)
@@ -685,7 +689,7 @@ class SequenceOfEncoder(AbstractItemEncoder):
                 chunk = encodeFun(chunk, wrapType, **options)
 
                 if LOG:
-                    LOG(f"wrapped with wrap type {wrapType!r}")
+                    LOG("wrapped with wrap type %r" % (wrapType,))
 
             chunks.append(chunk)
 
@@ -731,7 +735,7 @@ class AnyEncoder(OctetStringEncoder):
         return value, not options.get("defMode", True), True
 
 
-TAG_MAP = {
+tagMap = {
     eoo.endOfOctets.tagSet: EndOfOctetsEncoder(),
     univ.Boolean.tagSet: BooleanEncoder(),
     univ.Integer.tagSet: IntegerEncoder(),
@@ -764,7 +768,7 @@ TAG_MAP = {
 }
 
 # Put in ambiguous & non-ambiguous types for faster codec lookup
-TYPE_MAP = {
+typeMap = {
     univ.Boolean.typeId: BooleanEncoder(),
     univ.Integer.typeId: IntegerEncoder(),
     univ.BitString.typeId: BitStringEncoder(),
@@ -799,16 +803,14 @@ TYPE_MAP = {
 }
 
 
-class SingleItemEncoder:
+class Encoder(object):
     fixedDefLengthMode = None
     fixedChunkSize = None
 
-    TAG_MAP = TAG_MAP
-    TYPE_MAP = TYPE_MAP
-
-    def __init__(self, **options):
-        self._tagMap = options.get("tagMap", self.TAG_MAP)
-        self._typeMap = options.get("typeMap", self.TYPE_MAP)
+    # noinspection PyDefaultArgument
+    def __init__(self, tagMap, typeMap={}):
+        self.__tagMap = tagMap
+        self.__typeMap = typeMap
 
     def __call__(self, value, asn1Spec=None, **options):
         try:
@@ -825,8 +827,8 @@ class SingleItemEncoder:
 
         if LOG:
             LOG(
-                "encoder called in %sdef mode, chunk size %s for type %s, "
-                "value:\n%s"
+                "encoder called in %sdef mode, chunk size %s for "
+                "type %s, value:\n%s"
                 % (
                     not options.get("defMode", True) and "in" or "",
                     options.get("maxChunkSize", 0),
@@ -844,12 +846,12 @@ class SingleItemEncoder:
             options.update(maxChunkSize=self.fixedChunkSize)
 
         try:
-            concreteEncoder = self._typeMap[typeId]
+            concreteEncoder = self.__typeMap[typeId]
 
             if LOG:
                 LOG(
-                    "using value codec %s chosen by type ID "
-                    "%s" % (concreteEncoder.__class__.__name__, typeId)
+                    "using value codec %s chosen by type ID %s"
+                    % (concreteEncoder.__class__.__name__, typeId)
                 )
 
         except KeyError:
@@ -862,39 +864,28 @@ class SingleItemEncoder:
             baseTagSet = tag.TagSet(tagSet.baseTag, tagSet.baseTag)
 
             try:
-                concreteEncoder = self._tagMap[baseTagSet]
+                concreteEncoder = self.__tagMap[baseTagSet]
 
             except KeyError:
-                raise error.PyAsn1Error(f"No encoder for {value!r} ({tagSet})")
+                raise error.PyAsn1Error("No encoder for %r (%s)" % (value, tagSet))
 
             if LOG:
                 LOG(
-                    "using value codec %s chosen by tagSet "
-                    "%s" % (concreteEncoder.__class__.__name__, tagSet)
+                    "using value codec %s chosen by tagSet %s"
+                    % (concreteEncoder.__class__.__name__, tagSet)
                 )
 
         substrate = concreteEncoder.encode(value, asn1Spec, self, **options)
 
         if LOG:
             LOG(
-                "codec %s built %s octets of substrate: %s\nencoder "
-                "completed"
+                "codec %s built %s octets of substrate: %s\nencoder completed"
                 % (concreteEncoder, len(substrate), debug.hexdump(substrate))
             )
 
         return substrate
 
 
-class Encoder:
-    SINGLE_ITEM_ENCODER = SingleItemEncoder
-
-    def __init__(self, **options):
-        self._singleItemEncoder = self.SINGLE_ITEM_ENCODER(**options)
-
-    def __call__(self, pyObject, asn1Spec=None, **options):
-        return self._singleItemEncoder(pyObject, asn1Spec=asn1Spec, **options)
-
-
 #: Turns ASN.1 object into BER octet stream.
 #:
 #: Takes any ASN.1 object (e.g. :py:class:`~pyasn1.type.base.PyAsn1Item` derivative)
@@ -946,4 +937,4 @@ class Encoder:
 #:    >>> encode(seq)
 #:    b'0\t\x02\x01\x01\x02\x01\x02\x02\x01\x03'
 #:
-encode = Encoder()
+encode = Encoder(tagMap, typeMap)
