@@ -6,19 +6,12 @@
 #
 import sys
 
-try:
-    import platform
-
-    implementation = platform.python_implementation()
-
-except (ImportError, AttributeError):
-    implementation = 'CPython'
-
 from pyasn1.compat.octets import oct2int, null, ensureString
 
 
 def from_bytes(octets, signed=False):
-    return int.from_bytes(bytes(octets), 'big', signed=signed)
+    return int.from_bytes(bytes(octets), "big", signed=signed)
+
 
 def to_bytes(value, signed=False, length=0):
     length = max(value.bit_length(), length)
@@ -26,7 +19,8 @@ def to_bytes(value, signed=False, length=0):
     if signed and length % 8 == 0:
         length += 1
 
-    return value.to_bytes(length // 8 + (length % 8 and 1 or 0), 'big', signed=signed)
+    return value.to_bytes(length // 8 + (length % 8 and 1 or 0), "big", signed=signed)
+
 
 def bitLength(number):
     return int(number).bit_length()
