@@ -14,9 +14,9 @@ oct2int = lambda x: x
 # noinspection PyPep8
 octs2ints = lambda x: x
 # noinspection PyPep8
-str2octs = lambda x: x.encode('iso-8859-1')
+str2octs = lambda x: x.encode("iso-8859-1")
 # noinspection PyPep8
-octs2str = lambda x: x.decode('iso-8859-1')
+octs2str = lambda x: x.decode("iso-8859-1")
 # noinspection PyPep8
 isOctetsType = lambda s: isinstance(s, bytes)
 # noinspection PyPep8
