@@ -17,7 +17,6 @@ from pyasn1.compat import octets
 
 
 class OctetsTestCase(BaseTestCase):
-
     def test_ints2octs(self):
         assert [1, 2, 3] == list(octets.ints2octs([1, 2, 3]))
 
@@ -37,33 +36,33 @@ class OctetsTestCase(BaseTestCase):
         assert 12 == octets.oct2int(bytes([12]))[0]
 
     def test_str2octs(self):
-        assert bytes([1, 2, 3]) == octets.str2octs('\x01\x02\x03')
+        assert bytes([1, 2, 3]) == octets.str2octs("\x01\x02\x03")
 
     def test_str2octs_empty(self):
-        assert not octets.str2octs('')
+        assert not octets.str2octs("")
 
     def test_octs2str(self):
-        assert '\x01\x02\x03' == octets.octs2str(bytes([1, 2, 3]))
+        assert "\x01\x02\x03" == octets.octs2str(bytes([1, 2, 3]))
 
     def test_octs2str_empty(self):
         assert not octets.octs2str(bytes([]))
 
     def test_isOctetsType(self):
-        assert octets.isOctetsType('abc') == False
+        assert octets.isOctetsType("abc") == False
         assert octets.isOctetsType(123) == False
         assert octets.isOctetsType(bytes()) == True
 
     def test_isStringType(self):
-        assert octets.isStringType('abc') == True
+        assert octets.isStringType("abc") == True
         assert octets.isStringType(123) == False
         assert octets.isStringType(bytes()) == False
 
     def test_ensureString(self):
-        assert 'abc'.encode() == octets.ensureString('abc'.encode())
+        assert "abc".encode() == octets.ensureString("abc".encode())
         assert bytes([1, 2, 3]) == octets.ensureString([1, 2, 3])
 
 
 suite = unittest.TestLoader().loadTestsFromModule(sys.modules[__name__])
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.TextTestRunner(verbosity=2).run(suite)
